@@ -174,6 +174,10 @@ class RedisCache():
     def srem(self, *keys):
         return self.conn.srem(*keys)
 
+    @func_metrics('redis')
+    def zrem(self, *keys):
+        return self.conn.zrem(*keys)
+
     '''cache'''
 
     def delete_table_cache(self, table_key):
